0.0.2 (2017-06-26)
------------------

- Migrate away from requireing BASE_URL to be set and just use flask's own url handling [halkeye]
- fix for __all__ to actually return the classes not the libraries (still learning about python3) [halkeye]
- Add all kinds of minor package data cleanup as reported by check-manifest and pyroma


0.0.1 (2017-06-21)
------------------

- Initial Release